============
Data Readers
============


BED files
----------
.. currentmodule:: glue_genes.glue_genomics_data.bed_factory

.. autosummary::
   :toctree: api/
   
   read_bed


BigWig files
-------------
.. currentmodule:: glue_genes.glue_genomics_data.bigwig_factory

.. autosummary::
   :toctree: api/
   
   read_bigwig


AnnData files
---------------
.. currentmodule:: glue_genes.glue_single_cell.anndata_factory

.. autosummary::
   :toctree: api/
   
   read_anndata


Spaceranger output folders
---------------------------
.. currentmodule:: glue_genes.glue_genomics_data.spaceranger_factory

.. autosummary::
   :toctree: api/
   
   read_spaceranger_directory


GeoJSON files
---------------
.. currentmodule:: glue_genes.glue_genomics_data.geojson_factory

.. autosummary::
   :toctree: api/
   
   read_geojson


OpenSlide Image Files
---------------------
.. currentmodule:: glue_genes.glue_genomics_data.openslide_factory

.. autosummary::
   :toctree: api/
   
   read_open_slide_as_zarr


OME-Zarr Image Files
---------------------
.. currentmodule:: glue_genes.glue_genomics_data.ome_zarr_factory

.. autosummary::
   :toctree: api/
   
   read_ome_zarr


Tifffile Image Files
---------------------
.. currentmodule:: glue_genes.glue_genomics_data.tifffile_factory

.. autosummary::
   :toctree: api/
   
   read_tifffile_as_zarr
